@@ -16,6 +16,7 @@ from synapseclient.core.exceptions import (
 from . import (
     annotations,
     createchallenge,
+    create_portal_challenge,
     challenge,
     cheat_detection,
     evaluation_queue,
@@ -81,6 +82,33 @@ def command_createchallenge(syn, args):
     return challenge_components
 
 
+def command_create_portal_challenge(syn, args):
+    """Creates a challenge on the Sage Challenge Portal.
+
+    >>> challengeutils create-portal-challenge "Challenge Name Here" [-n <int>]
+    """
+    challenge_components = create_portal_challenge.main(
+        syn, args.challenge_name, args.tasks_count, args.livesiteid
+    )
+    # component: project or team
+    # componentid: project id or teamid
+    urls = {}
+    for component, componentid in challenge_components.items():
+        if component.endswith("projectid"):
+            urls[component] = f"https://www.synapse.org/#!Synapse:{componentid}"
+        elif component.endswith("teamid"):
+            urls[component] = f"https://www.synapse.org/#!Team:{componentid}"
+    urls["name"] = args.challenge_name
+    text = (
+        "{name} (Production site): {live_projectid}",
+        "{name} (Staging site): {staging_projectid}",
+        "{name} (Participant team): {organizer_teamid}",
+        "{name} (Organizer team): {participant_teamid}",
+    )
+    print("\n" + "\n".join(text).format(**urls))
+    return challenge_components
+
+
 def command_query(syn, args):
     """Command line convenience function to call evaluation queue query
     Evaluation queues offer a separate query service from the rest of Synapse.
@@ -439,6 +467,26 @@ def build_parser():
     )
     parser_createchallenge.set_defaults(func=command_createchallenge)
 
+    parser_create_portal_challenge = subparsers.add_parser(
+        "create-portal-challenge",
+        help="Create a Sage Challenge Portal challenge from template",
+    )
+    parser_create_portal_challenge.add_argument("challenge_name", help="Challenge name")
+    parser_create_portal_challenge.add_argument(
+        "-t",
+        "--tasks_count",
+        type=int,
+        default=1,
+        help=("Number of challenge tasks (default: 1)"),
+    )
+    parser_create_portal_challenge.add_argument(
+        "--livesiteid",
+        help=(
+            "Option to specify the live site synapse Id" " there is already a live site"
+        ),
+    )
+    parser_create_portal_challenge.set_defaults(func=command_create_portal_challenge)
+
     parser_mirrorwiki = subparsers.add_parser(
         "mirror-wiki",
         help="Mirrors (sync) wiki pages by using the wikipage titles between "
