@@ -8,19 +8,20 @@ import sys
 import urllib
 
 import synapseclient
-from synapseclient.annotations import (is_submission_status_annotations,
-                                       to_submission_status_annotations)
+from synapseclient.annotations import (
+    is_submission_status_annotations,
+    to_submission_status_annotations,
+)
 from synapseclient.core.exceptions import SynapseHTTPError
 from synapseclient.core.utils import id_of
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
+
 # TODO: Deprecate once fully using submissionviews
-def _switch_annotation_permission(add_annotations,
-                                  existing_annotations,
-                                  force=False):
-    '''
+def _switch_annotation_permission(add_annotations, existing_annotations, force=False):
+    """
     Switch annotation permissions
     If you add a private annotation that appears in the public annotation,
     it should throw an error, or switch permissions
@@ -33,27 +34,30 @@ def _switch_annotation_permission(add_annotations,
 
     Returns:
         Existing annotations
-    '''
+    """
     check_key = [key in add_annotations for key in existing_annotations]
     if sum(check_key) == 0:
         pass
     elif sum(check_key) > 0 and force:
         # Filter out the annotations that have changed ACL
-        existing_annotations = {key: existing_annotations[key]
-                                for key in existing_annotations
-                                if key not in add_annotations}
+        existing_annotations = {
+            key: existing_annotations[key]
+            for key in existing_annotations
+            if key not in add_annotations
+        }
     else:
-        change_keys = [key for key in existing_annotations
-                       if key in add_annotations]
+        change_keys = [key for key in existing_annotations if key in add_annotations]
         raise ValueError(
             "You are trying to change the ACL of these annotation key(s): {}."
             " Either change the annotation key or specify "
-            "force=True".format(", ".join(change_keys)))
+            "force=True".format(", ".join(change_keys))
+        )
     return existing_annotations
 
+
 # TODO: Deprecate once fully using submissionviews
 def _submission_annotations_to_dict(annotations, is_private=True):
-    '''
+    """
     Convert private / public submission status objects to dictionary
 
     Args:
@@ -62,17 +66,21 @@ def _submission_annotations_to_dict(annotations, is_private=True):
 
     Returns:
         dictionary with annotation key value pairs
-    '''
-    annotation_dict = {annotation['key']: annotation['value']
-                       for annotation_type in annotations
-                       for annotation in annotations[annotation_type]
-                       if annotation_type not in ['scopeId', 'objectId'] and
-                       annotation['isPrivate'] == is_private}
+    """
+    annotation_dict = {
+        annotation["key"]: annotation["value"]
+        for annotation_type in annotations
+        for annotation in annotations[annotation_type]
+        if annotation_type not in ["scopeId", "objectId"]
+        and annotation["isPrivate"] == is_private
+    }
     return annotation_dict
 
+
 # TODO: Deprecate once fully using submissionviews
-def update_single_submission_status(status, add_annotations, is_private=True,
-                                    force=False):
+def update_single_submission_status(
+    status, add_annotations, is_private=True, force=False
+):
     """
     This will update a single submission's status
 
@@ -89,45 +97,45 @@ def update_single_submission_status(status, add_annotations, is_private=True,
         Updated submission status
     """
     existing_annots = status.get("annotations", dict())
-    private_annotations = _submission_annotations_to_dict(existing_annots,
-                                                          is_private=True)
+    private_annotations = _submission_annotations_to_dict(
+        existing_annots, is_private=True
+    )
 
-    public_annotations = _submission_annotations_to_dict(existing_annots,
-                                                         is_private=False)
+    public_annotations = _submission_annotations_to_dict(
+        existing_annots, is_private=False
+    )
 
     if not is_submission_status_annotations(add_annotations):
         private_added_annotations = add_annotations if is_private else dict()
         public_added_annotations = dict() if is_private else add_annotations
     else:
         private_added_annotations = _submission_annotations_to_dict(
-            add_annotations, is_private=True)
+            add_annotations, is_private=True
+        )
 
         public_added_annotations = _submission_annotations_to_dict(
-            add_annotations, is_private=False)
+            add_annotations, is_private=False
+        )
 
     # If you add a private annotation that appears in the public annotation,
     # it switches
-    private_annotations = _switch_annotation_permission(public_added_annotations,
-                                                        private_annotations,
-                                                        force)
+    private_annotations = _switch_annotation_permission(
+        public_added_annotations, private_annotations, force
+    )
 
-    public_annotations = _switch_annotation_permission(private_added_annotations,
-                                                       public_annotations,
-                                                       force)
+    public_annotations = _switch_annotation_permission(
+        private_added_annotations, public_annotations, force
+    )
 
     private_annotations.update(private_added_annotations)
     public_annotations.update(public_added_annotations)
 
-    priv = to_submission_status_annotations(private_annotations,
-                                            is_private=True)
-    pub = to_submission_status_annotations(public_annotations,
-                                           is_private=False)
+    priv = to_submission_status_annotations(private_annotations, is_private=True)
+    pub = to_submission_status_annotations(public_annotations, is_private=False)
     # Combined private and public annotations into
     # one Submission.Status.annotation
-    combined_annotations = {'stringAnnos': [],
-                            'longAnnos': [],
-                            'doubleAnnos': []}
-    for annotation_type in ['stringAnnos', 'longAnnos', 'doubleAnnos']:
+    combined_annotations = {"stringAnnos": [], "longAnnos": [], "doubleAnnos": []}
+    for annotation_type in ["stringAnnos", "longAnnos", "doubleAnnos"]:
         private_annotation = priv.get(annotation_type)
         public_annotation = pub.get(annotation_type)
         private_annotation_exists = private_annotation is not None
@@ -139,7 +147,7 @@ def update_single_submission_status(status, add_annotations, is_private=True,
         # Remove annotation key if doesn't exist
         if not private_annotation_exists and not public_annotation_exists:
             combined_annotations.pop(annotation_type)
-    status['annotations'] = combined_annotations
+    status["annotations"] = combined_annotations
     return status
 
 
@@ -164,14 +172,15 @@ def evaluation_queue_query(syn, uri, limit=20, offset=0):
 
     prev_num_results = sys.maxsize
     while prev_num_results > 0:
-        rest_uri = "/evaluation/submission/query?query=" + \
-            urllib.parse.quote_plus("{} limit {} offset {}".format(
-                uri, limit, offset))
+        rest_uri = "/evaluation/submission/query?query=" + urllib.parse.quote_plus(
+            "{} limit {} offset {}".format(uri, limit, offset)
+        )
         page = syn.restGET(rest_uri)
         # results = page['results'] if 'results' in page else page['children']
-        results = [{page['headers'][index]:value
-                    for index, value in enumerate(row['values'])}
-                   for row in page['rows']]
+        results = [
+            {page["headers"][index]: value for index, value in enumerate(row["values"])}
+            for row in page["rows"]
+        ]
         prev_num_results = len(results)
         for result in results:
             offset += 1
@@ -179,7 +188,7 @@ def evaluation_queue_query(syn, uri, limit=20, offset=0):
 
 
 def _change_annotation_acl(annotations, key, annotation_type, is_private=True):
-    '''
+    """
     Helper function to locate the existing annotation
 
     Args:
@@ -191,14 +200,16 @@ def _change_annotation_acl(annotations, key, annotation_type, is_private=True):
     Returns:
         Updated annotation key ACL
 
-    '''
+    """
     if annotations.get(annotation_type) is not None:
-        check = list(filter(lambda x: x.get('key') == key,
-                            annotations[annotation_type]))
+        check = list(
+            filter(lambda x: x.get("key") == key, annotations[annotation_type])
+        )
         if check:
-            check[0]['isPrivate'] = is_private
+            check[0]["isPrivate"] = is_private
     return annotations
 
+
 # TODO: Deprecate once fully using submissionviews
 def change_submission_annotation_acl(status, annotations, is_private=False):
     """
@@ -216,17 +227,22 @@ def change_submission_annotation_acl(status, annotations, is_private=False):
     submission_annotations = status.annotations
     for key in annotations:
         submission_annotations = _change_annotation_acl(
-            submission_annotations, key, "stringAnnos", is_private)
+            submission_annotations, key, "stringAnnos", is_private
+        )
         submission_annotations = _change_annotation_acl(
-            submission_annotations, key, "doubleAnnos", is_private)
+            submission_annotations, key, "doubleAnnos", is_private
+        )
         submission_annotations = _change_annotation_acl(
-            submission_annotations, key, "longAnnos", is_private)
+            submission_annotations, key, "longAnnos", is_private
+        )
     status.annotations = submission_annotations
     return status
 
+
 # TODO: Deprecate once fully using submissionviews
-def update_all_submissions_annotation_acl(syn, evaluationid, annotations,
-                                          status='SCORED', is_private=False):
+def update_all_submissions_annotation_acl(
+    syn, evaluationid, annotations, status="SCORED", is_private=False
+):
     """
     Function to change the acl of a list of known annotation keys on
     all submissions of a evaluation
@@ -238,16 +254,17 @@ def update_all_submissions_annotation_acl(syn, evaluationid, annotations,
         status: ALL, VALIDATED, INVALID
         is_private: whether the annotation is private or not, default to True
     """
-    status = None if status == 'ALL' else status
+    status = None if status == "ALL" else status
     bundle = syn.getSubmissionBundles(evaluationid, status=status)
     for _, status in bundle:
-        new_status = change_submission_annotation_acl(status, annotations,
-                                                      is_private=is_private)
+        new_status = change_submission_annotation_acl(
+            status, annotations, is_private=is_private
+        )
         syn.store(new_status)
 
 
-def change_submission_status(syn, submissionid, status='RECEIVED'):
-    '''
+def change_submission_status(syn, submissionid, status="RECEIVED"):
+    """
     Function to change a submission status
 
     Args:
@@ -257,16 +274,18 @@ def change_submission_status(syn, submissionid, status='RECEIVED'):
 
     Returns:
         Updated submission status
-    '''
+    """
     sub_status = syn.getSubmissionStatus(submissionid)
     sub_status.status = status
     sub_status = syn.store(sub_status)
     return sub_status
 
+
 # TODO: Can possibly deprecate once using submissionview
-def change_all_submission_status(syn, evaluationid, submission_status='SCORED',
-                                 change_to_status='VALIDATED'):
-    '''
+def change_all_submission_status(
+    syn, evaluationid, submission_status="SCORED", change_to_status="VALIDATED"
+):
+    """
     Function to change submission status of all submissions in a queue
     The defaults is to change submissions from SCORED -> VALIDATED
     This function can be useful for 'rescoring' submissions
@@ -278,16 +297,15 @@ def change_all_submission_status(syn, evaluationid, submission_status='SCORED',
                            change. Default is SCORED.
         change_to_status: Submission status to change a submission to.
                           Default is VALIDATED.
-    '''
-    submission_bundle = syn.getSubmissionBundles(evaluationid,
-                                                 status=submission_status)
+    """
+    submission_bundle = syn.getSubmissionBundles(evaluationid, status=submission_status)
     for _, status in submission_bundle:
         status.status = change_to_status
         syn.store(status)
 
 
 def _check_date_range(date_str, start_datetime, end_datetime):
-    '''
+    """
     Helper function to check if the date is within range
     Note: the date and time is in UTC
 
@@ -300,25 +318,21 @@ def _check_date_range(date_str, start_datetime, end_datetime):
 
     Returns:
         boolean
-    '''
+    """
     result = True
     if start_datetime is not None or end_datetime is not None:
-        date_obj = datetime.datetime.strptime(date_str,
-                                              '%Y-%m-%dT%H:%M:%S.%fZ')
+        date_obj = datetime.datetime.strptime(date_str, "%Y-%m-%dT%H:%M:%S.%fZ")
         if start_datetime is not None:
-            start_obj = datetime.datetime.strptime(start_datetime,
-                                                   '%Y-%m-%d %H:%M')
+            start_obj = datetime.datetime.strptime(start_datetime, "%Y-%m-%d %H:%M")
             result = date_obj >= start_obj
         if end_datetime is not None:
-            end_obj = datetime.datetime.strptime(end_datetime,
-                                                 '%Y-%m-%d %H:%M')
+            end_obj = datetime.datetime.strptime(end_datetime, "%Y-%m-%d %H:%M")
             result = date_obj <= end_obj
     return result
 
 
-def _get_contributors(syn, evaluationid, status,
-                      start_datetime, end_datetime):
-    '''
+def _get_contributors(syn, evaluationid, status, start_datetime, end_datetime):
+    """
     Helper function to get contributors from a given evaluation id.
     Note: the date and time is in UTC
 
@@ -333,20 +347,22 @@ def _get_contributors(syn, evaluationid, status,
 
     Returns:
         Set of contributors' user ids
-    '''
+    """
     bundles = syn.getSubmissionBundles(evaluationid, status=status)
     contributors = set()
     for sub, _ in bundles:
         if _check_date_range(sub.createdOn, start_datetime, end_datetime):
-            principalids = set(contributor['principalId']
-                               for contributor in sub.contributors)
+            principalids = set(
+                contributor["principalId"] for contributor in sub.contributors
+            )
             contributors.update(principalids)
     return contributors
 
 
-def get_contributors(syn, evaluationids, status='SCORED',
-                     start_datetime=None, end_datetime=None):
-    '''
+def get_contributors(
+    syn, evaluationids, status="SCORED", start_datetime=None, end_datetime=None
+):
+    """
     Function to get contributors from a list of evaluation ids
     Note: the date and time is in UTC
 
@@ -361,32 +377,35 @@ def get_contributors(syn, evaluationids, status='SCORED',
 
     Returns:
         Set of contributors' user ids
-    '''
+    """
     all_contributors = set()
     for evaluationid in evaluationids:
-        contributors = _get_contributors(syn, evaluationid, status,
-                                         start_datetime, end_datetime)
+        contributors = _get_contributors(
+            syn, evaluationid, status, start_datetime, end_datetime
+        )
         all_contributors = all_contributors.union(contributors)
     return all_contributors
 
 
 def list_evaluations(syn, project):
-    '''
+    """
     List evaluation queues of a Synapse project
 
     Args:
         syn: Synapse object
         project: Synapse id/entity of project
-    '''
+    """
     evaluations = syn.getEvaluationByContentSource(project)
     for evaluation in evaluations:
         logger.info(
-            "Evaluation- {name}({evalid})".format(name=evaluation.name,
-                                                  evalid=evaluation.id))
+            "Evaluation- {name}({evalid})".format(
+                name=evaluation.name, evalid=evaluation.id
+            )
+        )
 
 
 def download_submission(syn, submissionid, download_location=None):
-    '''
+    """
     Download submission and return json
 
     Args:
@@ -396,16 +415,18 @@ def download_submission(syn, submissionid, download_location=None):
 
     Returns:
         dict: submission json results
-    '''
+    """
     sub = syn.getSubmission(submissionid, downloadLocation=download_location)
-    entity = sub['entity']
-    result = {'docker_repository': sub.get("dockerRepositoryName"),
-              'docker_digest': sub.get("dockerDigest"),
-              'entity_id': entity['id'],
-              'entity_version': entity.get('versionNumber'),
-              'entity_type': entity.get('concreteType'),
-              'evaluation_id': sub['evaluationId'],
-              'file_path': sub['filePath']}
+    entity = sub["entity"]
+    result = {
+        "docker_repository": sub.get("dockerRepositoryName"),
+        "docker_digest": sub.get("dockerDigest"),
+        "entity_id": entity["id"],
+        "entity_version": entity.get("versionNumber"),
+        "entity_type": entity.get("concreteType"),
+        "evaluation_id": sub["evaluationId"],
+        "file_path": sub["filePath"],
+    }
     return result
 
 
@@ -422,10 +443,10 @@ def _get_submitter_name(syn, submitterid):
 
     try:
         user = syn.getUserProfile(submitterid)
-        submitter_name = user['userName']
+        submitter_name = user["userName"]
     except SynapseHTTPError:
         team = syn.getTeam(submitterid)
-        submitter_name = team['name']
+        submitter_name = team["name"]
     return submitter_name
 
 
